<?php

function module_init() 
{
	// Load all the modules that have been enabled in the system table.
	foreach (module_list(TRUE, FALSE) as $module) 
		drupal_load('module', $module);
  module_invoke_all('init');
}


define('DISABLED',0);
define('ENABLED',1);
define('REQUIRED',2);
function module_list($refresh = FALSE, $bootstrap = TRUE) 
{
	global $database;
	static $list;
	if($refresh) $list = array();
	if(!$list) 
	{
		// system modules
		$mod_system->name = "system";
		$mod_system->filename = "mod/system.mod.php";
		$mod_system->boot = 1;
		$mod_system->status = REQUIRED;

		$mod_user->name = "user";
		$mod_user->filename = "mod/user.mod.php";
		$mod_user->boot = 1;
		$mod_user->status = REQUIRED;

		$list = array();
		if ($bootstrap) $result = $database->query("SELECT name, filename, boot, status FROM system WHERE type = 'mod' AND boot = 1 ORDER BY idx ASC, filename ASC");
		else			$result = $database->query("SELECT name, filename, boot, status FROM system WHERE type = 'mod' ORDER BY idx ASC, filename ASC");

		$list[$mod_system->name] = $mod_system;
		$list[$mod_user->name] = $mod_user;

		while ($module = $database->fetch_object($result)) 
		{
			if(file_exists($module->filename))
			  $list[$module->name] = $module;
		}
    }
	return $list;
}

function mod_load_all() 
{
	$list = mod_list();
	foreach($list as $module) {
		if($module->status == ENABLED) 
		include_once("$module->filename");
	}
}

function mod_load($module) 
{
	$mod_file = "mod/$module.mod.php";
		if(file_exists($mod_file)){
			include_once($mod_file);
		}
		
		else{
			err("The module <b>$module</b> was not found!");
		}
	
	controller_load($module);
}

function controller_load($module) 
{

	$controller_file = "controller/$module.con.php";
	if(file_exists($controller_file)) { 
		return include_once($controller_file); 
	}
	else { 
		return err("The controller <b>$module</b> was not found!"); 
	}

}

function mod_exist($module) 
{
  $list = module_list();
  return array_key_exists($module, $list);
}

function mod_hook($module, $hook) 
{
  return function_exists($module .'_'. $hook);
}

//$args [0] - hook, [1...] - params
function mod_invoke() 
{
  $args = func_get_args();
  $module = array_shift($args);
  $hook = array_shift($args);
  $function = $module .'_'. $hook;
  if (function_exists($function))
    return call_user_func_array($function, $args);
}

//$args [0] - hook, [1...] - params
function mod_invoke_all() 
{
  $args = func_get_args();
  $hook = array_shift($args);
  $return = array();
  foreach (module_implements($hook) as $module) {
    $function = $module .'_'. $hook;
    $result = call_user_func_array($function, $args);
    if (isset($result) && is_array($result)) {
      $return = array_merge($return, $result);
    }
    else if (isset($result)) {
      $return[] = $result;
    }
  }
  return $return;
}

function mod_parse_request($var_name, $def_request=null)
{
	$q = postget($var_name,$def_request);
	if($q) return mod_parse_query($q);
}
function mod_parse_query($query)
{
	if(!$query) return;
	$request = (object)null;
	$request->query = $query;
	$request->args = explode('/',$request->query);
	$request->mod = str_replace('.','',array_shift($request->args));
	$request->action = plain_text(array_shift($request->args));
	$request->item = &$request->args[0];
	$request->subitem = &$request->args[1];
	return $request;
}
function mod_sync_request(&$request)
{
	$request->query = "{$request->mod}/{$request->action}/{$request->item}";
	$request->args = explode('/',$request->query);
	return $request->query;
}

?>